window.Gleam.initSearch([{"doc":"funsies","title":"funsies","content":"# Funsies\n\n&gt; A fun, friendly, and type-safe in-betweensies-ORM for Gleam! Compose type-safe SQL queries, generate decoders and types from schemas, and with a fun CLI!\n\nFull type-safety derived from your schema.\n\n## About\n\nFunsies is a fully type-safe in-betweensies-ORM (?) for Gleam. Obviously, there are other database tools for Gleam. But, I found that most of them felt too barebones for my taste. So, I built the library of my dreams.\n\nFunsies comes with a DSL for schema creation (these schemas are used throughout the rest of the package), a DSL for building queries (with an innovative, stack-based approach), and a CLI for generating boilerplate code from your schemas. All in one, simple package.\n\nThe schema allows for type checking, meaning the following will always be true:\n\n- You will not create a query asking for a column of type X to be equal to a value of type Y.\n- You will not insert values in the wrong order, or with the wrong types.\n- It will be pretty tough to make invalid queries.\n\n## Installation\n\n```bash\ngleam add funsies\n```\n\n## Usage\n\n&gt; THIS PART OF THE DOCS IS IN PROGRESSSSSSS\n\nTo define a schema, create a `schema` folder in your `src` directory. Then, create a `{name}.gleam` file in there, where `{name}` is the name of the schema you&#39;re creating. For example, I&#39;d create a `user.gleam` file with the following inside of it:\n\n```gleam\npub fn user() {\n  schema.create_table(&quot;user&quot;)\n  |&gt; schema.add_serial_column(&quot;id&quot;)\n  |&gt; schema.add_string_column(&quot;name&quot;, 255)\n  |&gt; schema.add_bool_column(&quot;is_active&quot;)\n}\n```\n\nThis is where the magic happens! This schema is the brains of your application. It tells Funsies how to create queries, type-check them, and generate pitch-perfect decoders. All with this little, **reusable** definition.\n\nTo create the necessary types and decoders, run the following command:\n\n```bash\ngleam run -m funsies\n```\n\nAnd thats it! You will now have decoders and types for your schema, as well as an `insert` command that is type-safe and ensures you are passing the correct values in the correct order. The decoders are used from the postgres driver to decode the results of your queries into the generated types. That way, you get easy-to-work-with and type-safe data.\n\n&gt; The ORM/query builder is a work in progress. Below is what we CURRENTLY have.\n\nTo create a query, you can use the `yummy` DSL.\n\nFor example:\n\n```gleam\nimport funsies/query/yummy as y\nimport schema/users\nimport gleam/io.{debug}\n\npub fn main() {\n  let table = users.users()\n\n  let query =y.new(table)\n  |&gt; y.select()\n  |&gt; y.where(\n    y.wb(table)\n    |&gt; y.equals(&quot;name&quot;, &quot;Alice&quot;)\n    |&gt; y.not()\n    |&gt; y.equals(&quot;id&quot;, 4)\n    |&gt; y.and()\n    |&gt; y.equals(&quot;id&quot;, 5)\n    |&gt; y.or()\n  )\n  |&gt; y.to_sql()\n\n  case query {\n    Ok(sql) =&gt; debug(sql)\n    Error(_) =&gt; debug(&quot;Error!&quot;)\n  }\n}\n```\n\nThis might look a bit weird at first. Don&#39;t worry! It is natural. Instead of usual composition of functions, we use a stack-based DSL. This allows for a neater, more readable syntax. This yummy query would look like this in a more traditional DSL:\n\n```gleam\ny.or(y.and(y.not(y.equals(&quot;name&quot;, &quot;Alice&quot;)), y.equals(&quot;id&quot;, 4)), y.equals(&quot;id&quot;, 5))\n```\n\nNow, you might see the issue with this &quot;traditional&quot; syntax. It is HARD. TO. READ! Why have an ugly syntax in such a beautiful language?\n\nSo, we use the stack-based DSL. It may take a bit of getting used to, but it&#39;s worth it!\n\nThere are other benefits to our DSL. For example, we have full type-safety. This is because we use the types directly in the DSL to build the query. This means that if you try to add a `String` where a `Bool` is expected, the type-checker will catch it. By expected I mean the type of the column that you are referencing (EVEN THOUGH YOU ARE JUST PASSING A STRING! Magic of the schema :D)\n\nThis could look like:\n\n```gleam\n|&gt; y.equals(&quot;name&quot;, 1) // Error, 1 is not a string. It knows that the name value of the column is a string, so it can&#39;t be compared to an int.\n|&gt; y.equals(&quot;is_active&quot;, &quot;true&quot;) // Error, &quot;true&quot; is not a bool\n```\n\nThis will be propogated throughout, and you will get an `Error` value for the query instead of an `Ok` value.\n\nWhile you can still make invalid queries with the yummy DSL, you will not be able to make some common errors (i.e. passing the wrong type of value). This is because funsies checks the schema, sees that the column named &quot;name&quot; is a `String` column, and also sees that you are trying to pass an `Int` to an `equals`. Thus, it will return an error! Pretty cool if I do say so myself 🤓\n\nYou can also insert values!\n\nSince you have a Schema, Funsies can generate type-safe insert functions for you! All you have to do is import `insert` from the `funs` (the folder with all the outputs from the codegen).\n\n```gleam\nimport funs/insert\nimport funsies/query/yummy as y\nimport schema/users\nimport gleam/io.{debug}\nimport funs/users.{}\n\npub fn main() {\n  let table = users.users()\n\n  let query = y.new(table)\n  |&gt; y.insert(users.UsersRow(&quot;John&quot;, True)) // This is type-safe!\n  |&gt; y.to_insert_sql()\n\n  case query {\n    Ok(sql) =&gt; debug(sql)\n    Error(_) =&gt; debug(&quot;Error!&quot;)\n  }\n}\n```\n\nThe reason it has to be generated is because of we want full type-safety + good code completeion and help.\n\n## Why do you say `in-betweensies-ORM`?\n\nI don&#39;t think `funsies` is a full-on ORM. I took a lot of inspiration from Ecto in the Phoenix/Elixir ecosystem. I think that it is a lot less bare-bones than some existing alternatives, but not as feature-rich (or heavy and difficult to learn) as a typical, traditional ORM.\n\nI&#39;m not sure what to call it! `in-betweensies-ORM`? `micro-ORM`? `mini-ORM`?\n\n## Contributing\n\nContributions in ANY way are super duper duper appreciated and encouraged! Leaving an issue, starring, or downloading and giving feedback are all amazing.\n\n## Docs\n\nDocs are **in progress**.\n","url":"index.html"},{"doc":"funsies/schema","title":"Column","content":"pub type Column {\n  StringColumn(name: String, size: Int)\n  IntColumn(name: String)\n  BoolColumn(name: String)\n  ForeignKeyColumn(\n    name: String,\n    references_table: String,\n    references_column: String,\n    references_type: String,\n  )\n  SerialColumn(name: String)\n}\n A &quot;column&quot; type. This helps with type safety! V v cool\nStringColumn(name: String, size: Int)\n\n\nIntColumn(name: String)\n\n\nBoolColumn(name: String)\n\n\nForeignKeyColumn(\n  name: String,\n  references_table: String,\n  references_column: String,\n  references_type: String,\n)\n\n\nSerialColumn(name: String)\n\n\nSynonyms:\nfunsies/schema.Column\nfunsies/schema Column","url":"funsies/schema.html#Column"},{"doc":"funsies/schema","title":"Table","content":"pub type Table {\n  Table(name: String, columns: List(Column))\n}\n A &quot;table&quot; type, with a name and a list of `column` types\n \nTable(name: String, columns: List(Column))\n\n\nSynonyms:\nfunsies/schema.Table\nfunsies/schema Table","url":"funsies/schema.html#Table"},{"doc":"funsies/schema","title":"add_bool_column","content":"pub fn add_bool_column(table: Table, name: String) -&gt; Table\n This adds a bool column to the table. \n \nSynonyms:\nfunsies/schema.add_bool_column\nfunsies/schema add_bool_column","url":"funsies/schema.html#add_bool_column"},{"doc":"funsies/schema","title":"add_foreign_key_column","content":"pub fn add_foreign_key_column(\n  table: Table,\n  name: String,\n  references_table: Table,\n  references_column: String,\n) -&gt; Result(Table, String)\n This adds a foreign key column to the table. \n To use it, pass the name, the referenced table, and the referenced column. And the coolest part? FULL type safety.\nSynonyms:\nfunsies/schema.add_foreign_key_column\nfunsies/schema add_foreign_key_column","url":"funsies/schema.html#add_foreign_key_column"},{"doc":"funsies/schema","title":"add_int_column","content":"pub fn add_int_column(table: Table, name: String) -&gt; Table\n This adds a int column to the table. \n \nSynonyms:\nfunsies/schema.add_int_column\nfunsies/schema add_int_column","url":"funsies/schema.html#add_int_column"},{"doc":"funsies/schema","title":"add_serial_column","content":"pub fn add_serial_column(table: Table, name: String) -&gt; Table\n A serial column. \n \nSynonyms:\nfunsies/schema.add_serial_column\nfunsies/schema add_serial_column","url":"funsies/schema.html#add_serial_column"},{"doc":"funsies/schema","title":"add_string_column","content":"pub fn add_string_column(\n  table: Table,\n  name: String,\n  size: Int,\n) -&gt; Table\n This adds a string column to the table. \n \nSynonyms:\nfunsies/schema.add_string_column\nfunsies/schema add_string_column","url":"funsies/schema.html#add_string_column"},{"doc":"funsies/schema","title":"create_table","content":"pub fn create_table(name: String) -&gt; Table\n Create table\n \nSynonyms:\nfunsies/schema.create_table\nfunsies/schema create_table","url":"funsies/schema.html#create_table"},{"doc":"funsies/schema","title":"generate_create_table_sql","content":"pub fn generate_create_table_sql(table: Table) -&gt; String\n This generates SQL to ceate the table. Does NOT run it\nSynonyms:\nfunsies/schema.generate_create_table_sql\nfunsies/schema generate_create_table_sql","url":"funsies/schema.html#generate_create_table_sql"},{"doc":"funsies/schema","title":"generate_drop_table_sql","content":"pub fn generate_drop_table_sql(table: Table) -&gt; String\n Generates code to drop the table. Pretty simple\nSynonyms:\nfunsies/schema.generate_drop_table_sql\nfunsies/schema generate_drop_table_sql","url":"funsies/schema.html#generate_drop_table_sql"},{"doc":"funsies/schema","title":"get_part_table","content":"pub fn get_part_table(\n  table: Table,\n  columns: List(String),\n) -&gt; Table\n This gets part of a table and reutnrs a new table\n \nSynonyms:\nfunsies/schema.get_part_table\nfunsies/schema get_part_table","url":"funsies/schema.html#get_part_table"},{"doc":"funsies/schema","title":"funsies/schema","content":" Schema! This is where the magic happens. Basically, this allows you to define type-safe, code-gen-able schemas\n that are used to interact with your database.\n You define them in a src/schema/{name_of_schema}.gleam.\n Then, define a function called {name_of_schema} and return a table object Created w the DSL\n ","url":"funsies/schema.html"},{"doc":"funsies/builders/by_id","title":"render","content":"pub fn render(table table: Table) -&gt; String\n\nSynonyms:\nfunsies/builders/by_id.render\nfunsies/builders/by_id render","url":"funsies/builders/by_id.html#render"},{"doc":"funsies/builders/by_id","title":"render_builder","content":"pub fn render_builder(table table: Table) -&gt; StringBuilder\n\nSynonyms:\nfunsies/builders/by_id.render_builder\nfunsies/builders/by_id render_builder","url":"funsies/builders/by_id.html#render_builder"},{"doc":"funsies/builders/by_id","title":"funsies/builders/by_id","content":"","url":"funsies/builders/by_id.html"},{"doc":"funsies/builders/get_all","title":"render","content":"pub fn render(table table: Table) -&gt; String\n\nSynonyms:\nfunsies/builders/get_all.render\nfunsies/builders/get_all render","url":"funsies/builders/get_all.html#render"},{"doc":"funsies/builders/get_all","title":"render_builder","content":"pub fn render_builder(table table: Table) -&gt; StringBuilder\n\nSynonyms:\nfunsies/builders/get_all.render_builder\nfunsies/builders/get_all render_builder","url":"funsies/builders/get_all.html#render_builder"},{"doc":"funsies/builders/get_all","title":"funsies/builders/get_all","content":"","url":"funsies/builders/get_all.html"},{"doc":"funsies/query/yummy","title":"Eq","content":"pub type Eq {\n  Equals(col: String, value: Value)\n  Not(Eq)\n  Or(Eq, Eq)\n  And(Eq, Eq)\n}\n Different types of equality. \nEquals(col: String, value: Value)\n\n\nNot(Eq)\n\n\nOr(Eq, Eq)\n\n\nAnd(Eq, Eq)\n\n\nSynonyms:\nfunsies/query/yummy.Eq\nfunsies/query/yummy Eq","url":"funsies/query/yummy.html#Eq"},{"doc":"funsies/query/yummy","title":"QueryBuilder","content":"pub type QueryBuilder {\n  QueryBuilder(\n    table: schema.Table,\n    select_columns: List(String),\n    where_clauses: List(Eq),\n    order_by_clauses: List(String),\n    insert_columns: List(String),\n    insert_values: List(Value),\n  )\n}\n This is what is passed through thge pipeline to (eventually) create the SQL query\n \nQueryBuilder(\n  table: schema.Table,\n  select_columns: List(String),\n  where_clauses: List(Eq),\n  order_by_clauses: List(String),\n  insert_columns: List(String),\n  insert_values: List(Value),\n)\n\n\nSynonyms:\nfunsies/query/yummy.QueryBuilder\nfunsies/query/yummy QueryBuilder","url":"funsies/query/yummy.html#QueryBuilder"},{"doc":"funsies/query/yummy","title":"Value","content":"pub type Value {\n  IntValue(Int)\n  StringValue(String)\n  BoolValue(Bool)\n  ErrorValue(String)\n}\n Value type. used for type checking as well as sql making\nIntValue(Int)\n\n\nStringValue(String)\n\n\nBoolValue(Bool)\n\n\nErrorValue(String)\n\n\nSynonyms:\nfunsies/query/yummy.Value\nfunsies/query/yummy Value","url":"funsies/query/yummy.html#Value"},{"doc":"funsies/query/yummy","title":"WhereBuilder","content":"pub type WhereBuilder {\n  WhereBuilder(table: schema.Table, clauses: List(Eq))\n}\n Passed thorugh the where pipeline\nWhereBuilder(table: schema.Table, clauses: List(Eq))\n\n\nSynonyms:\nfunsies/query/yummy.WhereBuilder\nfunsies/query/yummy WhereBuilder","url":"funsies/query/yummy.html#WhereBuilder"},{"doc":"funsies/query/yummy","title":"and","content":"pub fn and(builder: WhereBuilder) -&gt; WhereBuilder\n Takes the two most recent things and makes an AND clause\n \nSynonyms:\nfunsies/query/yummy.and\nfunsies/query/yummy and","url":"funsies/query/yummy.html#and"},{"doc":"funsies/query/yummy","title":"equals","content":"pub fn equals(\n  builder: WhereBuilder,\n  col: String,\n  value: a,\n) -&gt; WhereBuilder\n This adds an Equal value to the stack where `col` is a string representing a column in your table\n  and `value` is what it should be equal to. What is kinda cool is value can be anything but because of the types, it will automatically\n type check it and make sure the the type of v aligns with the type of the column that you specified. So handy!\n \nSynonyms:\nfunsies/query/yummy.equals\nfunsies/query/yummy equals","url":"funsies/query/yummy.html#equals"},{"doc":"funsies/query/yummy","title":"insert","content":"pub fn insert(\n  builder: QueryBuilder,\n  values: List(Value),\n) -&gt; QueryBuilder\n NOT CURRENTLY USED\nSynonyms:\nfunsies/query/yummy.insert\nfunsies/query/yummy insert","url":"funsies/query/yummy.html#insert"},{"doc":"funsies/query/yummy","title":"new","content":"pub fn new(table: Table) -&gt; QueryBuilder\n Initialize a new builder for the yummy.\nSynonyms:\nfunsies/query/yummy.new\nfunsies/query/yummy new","url":"funsies/query/yummy.html#new"},{"doc":"funsies/query/yummy","title":"not","content":"pub fn not(builder: WhereBuilder) -&gt; WhereBuilder\n Pops a value off the stack and wraps it in a Not\n Used to negate the most recent value\n Use after like an equals or something\nSynonyms:\nfunsies/query/yummy.not\nfunsies/query/yummy not","url":"funsies/query/yummy.html#not"},{"doc":"funsies/query/yummy","title":"or","content":"pub fn or(builder: WhereBuilder) -&gt; WhereBuilder\n\nSynonyms:\nfunsies/query/yummy.or\nfunsies/query/yummy or","url":"funsies/query/yummy.html#or"},{"doc":"funsies/query/yummy","title":"order_by","content":"pub fn order_by(\n  builder: QueryBuilder,\n  column: String,\n  direction: String,\n) -&gt; QueryBuilder\n Order by. \nSynonyms:\nfunsies/query/yummy.order_by\nfunsies/query/yummy order_by","url":"funsies/query/yummy.html#order_by"},{"doc":"funsies/query/yummy","title":"select","content":"pub fn select(builder: QueryBuilder) -&gt; QueryBuilder\n This (currently) selects all columns. Mandatory. Will hopefully eventually allow you to only select some, or maybe select things from other tables\nSynonyms:\nfunsies/query/yummy.select\nfunsies/query/yummy select","url":"funsies/query/yummy.html#select"},{"doc":"funsies/query/yummy","title":"to_insert_sql","content":"pub fn to_insert_sql(\n  builder: QueryBuilder,\n) -&gt; Result(String, String)\n Build the final SQL query whendoing an insert query.\nSynonyms:\nfunsies/query/yummy.to_insert_sql\nfunsies/query/yummy to_insert_sql","url":"funsies/query/yummy.html#to_insert_sql"},{"doc":"funsies/query/yummy","title":"to_sql","content":"pub fn to_sql(builder: QueryBuilder) -&gt; Result(String, String)\n Build the final sql query if using a select query\nSynonyms:\nfunsies/query/yummy.to_sql\nfunsies/query/yummy to_sql","url":"funsies/query/yummy.html#to_sql"},{"doc":"funsies/query/yummy","title":"w","content":"pub fn w(v: a) -&gt; Value\n Public function to wrap values.\nSynonyms:\nfunsies/query/yummy.w\nfunsies/query/yummy w","url":"funsies/query/yummy.html#w"},{"doc":"funsies/query/yummy","title":"wb","content":"pub fn wb(table: Table) -&gt; WhereBuilder\n This stands for where-builder. Makes a new `WhereBuilder` object\n \nSynonyms:\nfunsies/query/yummy.wb\nfunsies/query/yummy wb","url":"funsies/query/yummy.html#wb"},{"doc":"funsies/query/yummy","title":"where","content":"pub fn where(\n  builder: QueryBuilder,\n  condition: WhereBuilder,\n) -&gt; QueryBuilder\n This is where you put the wherebuilder.\nSynonyms:\nfunsies/query/yummy.where\nfunsies/query/yummy where","url":"funsies/query/yummy.html#where"},{"doc":"funsies/query/yummy","title":"funsies/query/yummy","content":" Yummy! Yummy is the main query builder in funsies. It takes an approach I haven&#39;t seen very often: stack-based. Basically, each operation (especially seen in the `where` function)\n operates on a stack. Meaning that instead of doing something like:\n ```and(equals(&quot;id&quot;, 2), not(equals(&quot;name&quot;, &quot;Asher&quot;)))```\n You would do something like:\n equals(&quot;id&quot;, 2)\n |&gt; equals(&quot;name&quot;, &quot;Asher&quot;)\n |&gt; not()\n |&gt; and()\n You catch my drift? Basically things like `not` pop a clause off the stack then wrap it in a Not and append it back. Pretty cool!\n ","url":"funsies/query/yummy.html"},{"doc":"funsies/builders/insert","title":"render","content":"pub fn render(table table: Table) -&gt; String\n\nSynonyms:\nfunsies/builders/insert.render\nfunsies/builders/insert render","url":"funsies/builders/insert.html#render"},{"doc":"funsies/builders/insert","title":"render_builder","content":"pub fn render_builder(table table: Table) -&gt; StringBuilder\n\nSynonyms:\nfunsies/builders/insert.render_builder\nfunsies/builders/insert render_builder","url":"funsies/builders/insert.html#render_builder"},{"doc":"funsies/builders/insert","title":"funsies/builders/insert","content":"","url":"funsies/builders/insert.html"},{"doc":"funsies/orm_gen","title":"create_by_id","content":"pub fn create_by_id(\n  path: String,\n  table: Table,\n) -&gt; Result(Nil, FileError)\n\nSynonyms:\nfunsies/orm_gen.create_by_id\nfunsies/orm_gen create_by_id","url":"funsies/orm_gen.html#create_by_id"},{"doc":"funsies/orm_gen","title":"create_get_all","content":"pub fn create_get_all(\n  path: String,\n  table: Table,\n) -&gt; Result(Nil, FileError)\n\nSynonyms:\nfunsies/orm_gen.create_get_all\nfunsies/orm_gen create_get_all","url":"funsies/orm_gen.html#create_get_all"},{"doc":"funsies/orm_gen","title":"create_insert","content":"pub fn create_insert(\n  path: String,\n  table: Table,\n) -&gt; Result(Nil, FileError)\n uses the insert template to create a type-safe insert function!\nSynonyms:\nfunsies/orm_gen.create_insert\nfunsies/orm_gen create_insert","url":"funsies/orm_gen.html#create_insert"},{"doc":"funsies/orm_gen","title":"funsies/orm_gen","content":"","url":"funsies/orm_gen.html"},{"doc":"funsies/cli_project/project","title":"create_files","content":"pub fn create_files(\n  input: Dict(String, String),\n) -&gt; Result(Nil, FileError)\n This has a bad name. Basically what it does is create the generate file, which is used to generate the types, decoders, and the `insert` function.\n The reason the insert function has to be generated is because it felt like the easiest way to maintain complete type-safety.\n \nSynonyms:\nfunsies/cli_project/project.create_files\nfunsies/cli_project/project create_files","url":"funsies/cli_project/project.html#create_files"},{"doc":"funsies/cli_project/project","title":"find_schema_files","content":"pub fn find_schema_files() -&gt; Result(Dict(String, String), Nil)\n Finds the schema files (looks in src/schema/*.gleam), and returns them as a dictionary of the file_path and the name of the schema (by removing everything except hte final clause without the extensions)\n \nSynonyms:\nfunsies/cli_project/project.find_schema_files\nfunsies/cli_project/project find_schema_files","url":"funsies/cli_project/project.html#find_schema_files"},{"doc":"funsies/cli_project/project","title":"name","content":"pub fn name() -&gt; Result(String, Nil)\n Returns the project&#39;s name, read from the `gleam.toml` file.\n FROM SQUIRREL PROJECT, TYSM\n \nSynonyms:\nfunsies/cli_project/project.name\nfunsies/cli_project/project name","url":"funsies/cli_project/project.html#name"},{"doc":"funsies/cli_project/project","title":"src","content":"pub fn src() -&gt; String\n Finds the path of the project&#39;s `src` directory.\n This recursively walks up from the current directory until it finds a\n `gleam.toml` and builds it from there.\n FROM SQUIRRLE PROJECT, TYSM\n \nSynonyms:\nfunsies/cli_project/project.src\nfunsies/cli_project/project src","url":"funsies/cli_project/project.html#src"},{"doc":"funsies/cli_project/project","title":"work","content":"pub fn work() -&gt; Result(Nil, Nil)\n Also a really bad name haha. This function is just a helper to run the gleam code that creates everything (the generate file).\n \nSynonyms:\nfunsies/cli_project/project.work\nfunsies/cli_project/project work","url":"funsies/cli_project/project.html#work"},{"doc":"funsies/cli_project/project","title":"funsies/cli_project/project","content":" A set of utilities to work within a Gleam project and to make the CLI work. Some functions are from the Squirre repo, thanks so much!\n These help me orient myself within a gleam project, and also the creation of the `generate.gleam` file which is used to actually generate the code. \n ","url":"funsies/cli_project/project.html"},{"doc":"funsies","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nfunsies.main\nfunsies main","url":"funsies.html#main"},{"doc":"funsies","title":"funsies","content":"","url":"funsies.html"},{"doc":"funsies/decoder","title":"generate_decoder_code","content":"pub fn generate_decoder_code(table: Table) -&gt; String\n\nSynonyms:\nfunsies/decoder.generate_decoder_code\nfunsies/decoder generate_decoder_code","url":"funsies/decoder.html#generate_decoder_code"},{"doc":"funsies/decoder","title":"generate_row_type","content":"pub fn generate_row_type(table: Table) -&gt; String\n\nSynonyms:\nfunsies/decoder.generate_row_type\nfunsies/decoder generate_row_type","url":"funsies/decoder.html#generate_row_type"},{"doc":"funsies/decoder","title":"funsies/decoder","content":"","url":"funsies/decoder.html"},{"doc":"funsies/query/runner","title":"run","content":"pub fn run(\n  sql: String,\n  db: Connection,\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(Returned(a), QueryError)\n The only function. Runs the query, given a sql query, a db connection, and a decoder\n \nSynonyms:\nfunsies/query/runner.run\nfunsies/query/runner run","url":"funsies/query/runner.html#run"},{"doc":"funsies/query/runner","title":"funsies/query/runner","content":" A super small module. This just makes it easier to run the queries from `yummy`\n ","url":"funsies/query/runner.html"}]);